<?php
/*
  $Id$
  Slim Checkout 1.4
  by @raiwa Rainer Schmied
  info@oscaddons.com
  www.oscaddons.com

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2021 Rainer Schmied

  Released under the GNU General Public License
*/

  class st_slim_checkout extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_STORE_SLIM_CHECKOUT_';

    public function __construct() {
      parent::__construct(__FILE__);

    }

    function execute() {

    }

    protected function get_parameters() {
      return [
        'MODULE_STORE_SLIM_CHECKOUT_VERSION' => [
          'title' => 'Current Version',
          'value' => '1.4',
          'desc' => 'Version info. It is read only',
          'set_func' => 'st_slim_checkout::readonly(',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_STATUS' => [
          'title' => 'Enable Slim Checkout',
          'value' => 'True',
          'desc' => 'Enable this module?',
          'set_func' => "tep_cfg_select_option(['True', 'False'], ",
        ],
        'MODULE_STORE_SLIM_CHECKOUT_NAVBAR' => [
          'title' => 'Hide Navbar',
          'value' => '',
          'desc' => 'Hide the Navabar module on Checkout Pages?',
          'set_func' => 'st_slim_navbar_edit_pages(',
          'use_func' => 'st_slim_navbar_show_pages',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_HEADER' => [
          'title' => 'Hide Header Area Modules',
          'value' => implode(';', $this->get_default_pages()),
          'desc' => 'Hide the modules in the Header Area on Checkout Pages?',
          'set_func' => 'st_slim_header_edit_pages(',
          'use_func' => 'st_slim_header_show_pages',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_BOXES' => [
          'title' => 'Hide Side Column Boxes',
          'value' => implode(';', $this->get_default_pages()),
          'desc' => 'Hide the Side Column Boxes on Checkout Pages?',
          'set_func' => 'st_slim_boxes_edit_pages(',
          'use_func' => 'st_slim_boxes_show_pages',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_FOOTER' => [
          'title' => 'Hide Footer Modules',
          'value' => '0',
          'desc' => 'Hide the Footer Modules on Checkout Pages?',
          'set_func' => 'st_slim_footer_edit_pages(',
          'use_func' => 'st_slim_footer_show_pages',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_FOOTER_SUFFIX' => [
          'title' => 'Hide Footer Suffix Modules',
          'value' => '0',
          'desc' => 'Hide the Footer Suffix Modules on Checkout Pages?',
          'set_func' => 'st_slim_footer_suffix_edit_pages(',
          'use_func' => 'st_slim_footer_suffix_show_pages',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_EXCLUDE' => [
          'title' => 'Exclude Header Modules',
          'value' => 'cm_header_logo',
          'desc' => 'List of modules to show always in the header area, even the header module area is hidden?<br>Comma separated list.<br>Only for header modules: \"cm_header_...\"',
          'set_func' => 'st_slim_checkout::tep_textarea(',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_CONTENT_WIDTH' => [
          'title' => 'Content Width',
          'value' => '8',
          'desc' => 'Content width if side columns are hidden.<br>Should be a pair value between the normal main content width (default = 8) => no content stretch, and the max width (12) => stretch content to full width.<br>Usual values: 8, 10 or 12',
        ],
        'MODULE_STORE_SLIM_CHECKOUT_SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '0',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
      ];
    }
    
    public static function readonly($value) {
      return $value;
    }

    public static function tep_textarea($text, $key = '') {
      $name = (($key) ? 'configuration[' . $key . ']' : 'configuration_value');
      return tep_draw_textarea_field($name, false, 35, 5, $text, 'style="font: inherit;"');
    }
   
    public function get_default_pages() {
      return array('checkout_shipping.php',
                   'checkout_payment.php',
                   'checkout_confirmation.php');
    }
    
  } // end class

  function st_slim_navbar_show_pages($text) {
    return nl2br(implode("\n", explode(';', $text)));
  }

  function st_slim_navbar_edit_pages($values, $key) {
    global $PHP_SELF;

    $files_array = get_controlled_pages();

    $values_array = explode(';', $values);

    $output = '';
    foreach ($files_array as $file) {
      $output .= tep_draw_checkbox_field('st_slim_navbar_file[]', $file, in_array($file, $values_array)) . '&nbsp;' . tep_output_string($file) . '<br />';
    }

    if (!empty($output)) {
      $output = '<br />' . substr($output, 0, -6);
    }

    $output .= tep_draw_hidden_field('configuration[' . $key . ']', '', 'id="htrn_navbar_files"');

    $output .= '<script>
                function htrn_navbar_update_cfg_value() {
                  var htrn_navbar_selected_files = \'\';

                  if ($(\'input[name="st_slim_navbar_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_navbar_file[]"]:checked\').each(function() {
                      htrn_navbar_selected_files += $(this).attr(\'value\') + \';\';
                    });

                    if (htrn_navbar_selected_files.length > 0) {
                      htrn_navbar_selected_files = htrn_navbar_selected_files.substring(0, htrn_navbar_selected_files.length - 1);
                    }
                  }

                  $(\'#htrn_navbar_files\').val(htrn_navbar_selected_files);
                }

                $(function() {
                  htrn_navbar_update_cfg_value();

                  if ($(\'input[name="st_slim_navbar_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_navbar_file[]"]\').change(function() {
                      htrn_navbar_update_cfg_value();
                    });
                  }
                });
                </script>';

    return $output;
  }
  
  function st_slim_header_show_pages($text) {
    return nl2br(implode("\n", explode(';', $text)));
  }

  function st_slim_header_edit_pages($values, $key) {
    global $PHP_SELF;

    $files_array = get_controlled_pages();

    $values_array = explode(';', $values);

    $output = '';
    foreach ($files_array as $file) {
      $output .= tep_draw_checkbox_field('st_slim_header_file[]', $file, in_array($file, $values_array)) . '&nbsp;' . tep_output_string($file) . '<br />';
    }

    if (!empty($output)) {
      $output = '<br />' . substr($output, 0, -6);
    }

    $output .= tep_draw_hidden_field('configuration[' . $key . ']', '', 'id="htrn_header_files"');

    $output .= '<script>
                function htrn_header_update_cfg_value() {
                  var htrn_header_selected_files = \'\';

                  if ($(\'input[name="st_slim_header_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_header_file[]"]:checked\').each(function() {
                      htrn_header_selected_files += $(this).attr(\'value\') + \';\';
                    });

                    if (htrn_header_selected_files.length > 0) {
                      htrn_header_selected_files = htrn_header_selected_files.substring(0, htrn_header_selected_files.length - 1);
                    }
                  }

                  $(\'#htrn_header_files\').val(htrn_header_selected_files);
                }

                $(function() {
                  htrn_header_update_cfg_value();

                  if ($(\'input[name="st_slim_header_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_header_file[]"]\').change(function() {
                      htrn_header_update_cfg_value();
                    });
                  }
                });
                </script>';

    return $output;
  }

  function st_slim_boxes_show_pages($text) {
    return nl2br(implode("\n", explode(';', $text)));
  }

  function st_slim_boxes_edit_pages($values, $key) {
    global $PHP_SELF;

    $files_array = get_controlled_pages();

    $values_array = explode(';', $values);

    $output = '';
    foreach ($files_array as $file) {
      $output .= tep_draw_checkbox_field('st_slim_boxes_file[]', $file, in_array($file, $values_array)) . '&nbsp;' . tep_output_string($file) . '<br />';
    }

    if (!empty($output)) {
      $output = '<br />' . substr($output, 0, -6);
    }

    $output .= tep_draw_hidden_field('configuration[' . $key . ']', '', 'id="htrn_boxes_files"');

    $output .= '<script>
                function htrn_boxes_update_cfg_value() {
                  var htrn_boxes_selected_files = \'\';

                  if ($(\'input[name="st_slim_boxes_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_boxes_file[]"]:checked\').each(function() {
                      htrn_boxes_selected_files += $(this).attr(\'value\') + \';\';
                    });

                    if (htrn_boxes_selected_files.length > 0) {
                      htrn_boxes_selected_files = htrn_boxes_selected_files.substring(0, htrn_boxes_selected_files.length - 1);
                    }
                  }

                  $(\'#htrn_boxes_files\').val(htrn_boxes_selected_files);
                }

                $(function() {
                  htrn_boxes_update_cfg_value();

                  if ($(\'input[name="st_slim_boxes_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_boxes_file[]"]\').change(function() {
                      htrn_boxes_update_cfg_value();
                    });
                  }
                });
                </script>';

    return $output;
  }

  function st_slim_footer_show_pages($text) {
    return nl2br(implode("\n", explode(';', $text)));
  }

  function st_slim_footer_edit_pages($values, $key) {
    global $PHP_SELF;

    $files_array = get_controlled_pages();

    $values_array = explode(';', $values);

    $output = '';
    foreach ($files_array as $file) {
      $output .= tep_draw_checkbox_field('st_slim_footer_file[]', $file, in_array($file, $values_array)) . '&nbsp;' . tep_output_string($file) . '<br />';
    }

    if (!empty($output)) {
      $output = '<br />' . substr($output, 0, -6);
    }

    $output .= tep_draw_hidden_field('configuration[' . $key . ']', '', 'id="htrn_footer_files"');

    $output .= '<script>
                function htrn_footer_update_cfg_value() {
                  var htrn_footer_selected_files = \'\';

                  if ($(\'input[name="st_slim_footer_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_footer_file[]"]:checked\').each(function() {
                      htrn_footer_selected_files += $(this).attr(\'value\') + \';\';
                    });

                    if (htrn_footer_selected_files.length > 0) {
                      htrn_footer_selected_files = htrn_footer_selected_files.substring(0, htrn_footer_selected_files.length - 1);
                    }
                  }

                  $(\'#htrn_footer_files\').val(htrn_footer_selected_files);
                }

                $(function() {
                  htrn_footer_update_cfg_value();

                  if ($(\'input[name="st_slim_footer_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_footer_file[]"]\').change(function() {
                      htrn_footer_update_cfg_value();
                    });
                  }
                });
                </script>';

    return $output;
  }

  function st_slim_footer_suffix_show_pages($text) {
    return nl2br(implode("\n", explode(';', $text)));
  }

  function st_slim_footer_suffix_edit_pages($values, $key) {
    global $PHP_SELF;

    $files_array = get_controlled_pages();
    
    $values_array = explode(';', $values);

    $output = '';
    foreach ($files_array as $file) {
      $output .= tep_draw_checkbox_field('st_slim_footer_suffix_file[]', $file, in_array($file, $values_array)) . '&nbsp;' . tep_output_string($file) . '<br />';
    }

    if (!empty($output)) {
      $output = '<br />' . substr($output, 0, -6);
    }

    $output .= tep_draw_hidden_field('configuration[' . $key . ']', '', 'id="htrn_footer_suffix_files"');

    $output .= '<script>
                function htrn_footer_suffix_update_cfg_value() {
                  var htrn_footer_suffix_selected_files = \'\';

                  if ($(\'input[name="st_slim_footer_suffix_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_footer_suffix_file[]"]:checked\').each(function() {
                      htrn_footer_suffix_selected_files += $(this).attr(\'value\') + \';\';
                    });

                    if (htrn_footer_suffix_selected_files.length > 0) {
                      htrn_footer_suffix_selected_files = htrn_footer_suffix_selected_files.substring(0, htrn_footer_suffix_selected_files.length - 1);
                    }
                  }

                  $(\'#htrn_footer_suffix_files\').val(htrn_footer_suffix_selected_files);
                }

                $(function() {
                  htrn_footer_suffix_update_cfg_value();

                  if ($(\'input[name="st_slim_footer_suffix_file[]"]\').length > 0) {
                    $(\'input[name="st_slim_footer_suffix_file[]"]\').change(function() {
                      htrn_footer_suffix_update_cfg_value();
                    });
                  }
                });
                </script>';

    return $output;
  }
  
  function get_controlled_pages() {
    $files_array = array('login.php',
                         'shopping_cart.php',
                         'checkout_shipping.php',
                         'checkout_payment.php',
                         'checkout_confirmation.php',
                         'checkout_success.php');    
    return $files_array;
  }
