<?php
/*
  $Id$
  
  Slim Checkout 1.4
  by @raiwa Rainer Schmied
  info@oscaddons.com
  www.oscaddons.com

  Copyright (c) 2021 Rainer Schmied

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2020 osCommerce

  Released under the GNU General Public License
*/

  class oscTemplate {

    private $_title;
    private $_blocks = [];
    private $_content = [];
    public $_data = [];
    private $_template;
    public $_hide_column = false;

    public function __construct($template = null) {
      if (is_object($template)) {
        $this->_template = $template;
      } else {
        if (is_null($template)) {
          $template = TEMPLATE_SELECTION;
        }

        $template .= '_template';
        $this->_template = new $template();
      }
    }

    public function getGridContentWidth() {
      if ( $this->_hide_column == true ) {
        return MODULE_STORE_SLIM_CHECKOUT_CONTENT_WIDTH; // define main content width if side columns are hidden
      } else {
        return $this->_grid_content_width;
      }
    }

    public function getGridColumnWidth() {
      if ( $this->_hide_column == true ) { // define columns width if side columns are hidden
        return (12 - MODULE_STORE_SLIM_CHECKOUT_CONTENT_WIDTH) / 2;
      } else {
        return (12 - BOOTSTRAP_CONTENT) / 2;
      }
    }

    public function get_template() {
      return $this->_template;
    }

    public function setTitle($title) {
      $this->_title = $title;
    }

    public function getTitle() {
      return $this->_title;
    }

    public function addBlock($block, $group) {
      $this->_blocks[$group][] = $block;
    }

    public function hasBlocks($group) {
      return !empty($this->_blocks[$group]);
    }

    public function getBlocks($group) {

      if ( $this->hasBlocks($group) && ((strpos($group, 'boxes_column') === false) || !in_array(basename($GLOBALS['PHP_SELF']), $this->checkPages('bm_'))) ) { // hide side columns
        return implode("\n", $this->_blocks[$group]);
      }
    }

    public function buildBlocks() {
      if ( !defined('TEMPLATE_BLOCK_GROUPS') || !tep_not_null(TEMPLATE_BLOCK_GROUPS) ) {
        return;
      }

      foreach (explode(';', TEMPLATE_BLOCK_GROUPS) as $group) {
        $module_key = 'MODULE_' . strtoupper($group) . '_INSTALLED';

        if ( !defined($module_key) || !tep_not_null(constant($module_key)) ) {
          continue;
        }

        foreach ( explode(';', constant($module_key)) as $module ) {
          $class = pathinfo($module, PATHINFO_FILENAME);

          if ( class_exists($class) ) {
            $mb = new $class();

            if ( $mb->isEnabled() ) {
              $mb->execute();
            }
          }
        }
      }
    }

    public function addContent($content, $group) {
      $this->_content[$group][] = $content;
    }

    public function hasContent($group) {
      return !empty($this->_content[$group]);
    }

    public function getContent($group) {
                                  

      $template_page_class = 'tp_' . $group;
                                                                
       

                                           
      if ( class_exists($template_page_class) ) {
        $template_page = new $template_page_class();
        $template_page->prepare();
      }

      foreach ( $this->getContentModules($group) as $module ) {
        if ( class_exists($module) ) {
          $mb = new $module();
           if ( $mb->isEnabled() && !in_array(basename($GLOBALS['PHP_SELF']), $this->checkPages($module))) { // check if module should be hidden, get hidden pages array
            $mb->execute();
          }
        }
      }

      if ( class_exists('tp_' . $group) ) {
        $template_page->build();
      }

      $parameters = [
        'group' => $group,
        'content' => &$this->_content[$group],
      ];
      $GLOBALS['OSCOM_Hooks']->call('siteWide', 'getContent', $parameters);
      if ($this->hasContent($group)) {
        return implode("\n", $this->_content[$group]);
      }
    }

    public function getContentModules($group) {
      $result = [];

      foreach ( explode(';', MODULE_CONTENT_INSTALLED) as $m ) {
        $module = explode('/', $m, 2);

        if ( $module[0] == $group ) {
          $result[] = $module[1];
        }
      }

      $parameters = [ 'results' => &$results ];
      $GLOBALS['OSCOM_Hooks']->call('siteWide', 'getContentModules', $parameters);
      return $result;
    }

    public function map_to_template($file, $type = 'module') {
      return $this->_template->get_template_mapping_for($file, $type)
          ?? default_template::_get_template_mapping_for($file, $type);
    }

    public function checkPages($module){ //$module what is called in the and content modules

        if (strtok($module, '_') == 'bm') {
          $module_group_prefix = strtok($module, '_');
        } elseif ((strpos($module, 'cm_footer_extra') !== false)) {
          $module_group_prefix = 'footer_extra';
        } elseif (strtok($module, '_') == 'cm') {
          $module_group_prefix = (strtok($module, '_'.strtok($module, '_')));
        }
        
        $hide_array[$module_group_prefix] = [];
        
        $hide_array['navbar'] =  explode(';', MODULE_STORE_SLIM_CHECKOUT_NAVBAR);
        if ( !in_array($module, explode(',', MODULE_STORE_SLIM_CHECKOUT_EXCLUDE)) ) {
          $hide_array['header'] =  explode(';', MODULE_STORE_SLIM_CHECKOUT_HEADER);
        }
        $hide_array['bm'] =  explode(';', MODULE_STORE_SLIM_CHECKOUT_BOXES);
        $hide_array['footer'] =  explode(';', MODULE_STORE_SLIM_CHECKOUT_FOOTER);
        $hide_array['footer_extra'] =  explode(';', MODULE_STORE_SLIM_CHECKOUT_FOOTER_SUFFIX);

        // check if side columns are hidden
        if (in_array(basename($GLOBALS['PHP_SELF']), $hide_array['bm'])) $this->_hide_column = true;          

        return $hide_array[$module_group_prefix];
    }

  }
